package Devel::Declare::Lexer::Stream;

use v5;
use Tie::Array;

our @ISA = ('Tie::StdArray');

1;
